@@ -3,7 +3,7 @@ import argparse
 from FLF import RpcConnector
 
 
-if __name__ == "__main__":
+def main():
     parser = argparse.ArgumentParser(description="Example RPCServer for RabbitMQ")
     parser.add_argument("--host", default="localhost", type=str, help="host")
     parser.add_argument("--port", default=5672, type=int, help="port")
@@ -19,3 +19,7 @@ if __name__ == "__main__":
     print(response)
     print(files)
 
+
+if __name__ == "__main__":
+    main()
+
